@@ -665,10 +665,8 @@ void KSWindsScreenSaver::setMode( int id )
 
 
 #include <qlayout.h>
-#include <qpushbutton.h>
 #include <qlabel.h>
 #include <qcombobox.h>
-#include <kbuttonbox.h>
 #include <kmessagebox.h>
 
 
@@ -686,75 +684,40 @@ static const char* defaultText[] =
 
 
 KSWindsSetup::KSWindsSetup( QWidget* parent, const char* name )
-                      : QDialog( parent, name )
+        : KDialogBase( parent, name, true, i18n( "Setup Solar Wind" ),
+          Ok|Cancel|Help, Ok, true )
 {
-    setCaption( i18n("Setup Solar Wind Screen Saver") );
-
-    QVBoxLayout* top    = new QVBoxLayout(this, 10, 10);
-    QHBoxLayout* across = new QHBoxLayout;
-    top->addLayout( across );
+    setButtonText( Help, i18n( "A&bout" ) );
+    QWidget *main = makeMainWidget();
 
+    QHBoxLayout* top = new QHBoxLayout( main, 0, spacingHint() );
 
     QVBoxLayout* leftCol = new QVBoxLayout;
-    across->addLayout( leftCol );
+    top->addLayout( leftCol );
 
-    leftCol->addStretch( 1 );
+    QLabel* label = new QLabel( i18n("Mode:"), main );
+    leftCol->addWidget( label );
 
-
-    // Parameters
-    QHBoxLayout* lo = new QHBoxLayout;
-    leftCol->addLayout(lo);
-
-    lo->addStretch(1);
-
-    QLabel* label = new QLabel( i18n("Mode:"), this );
-    label->setAlignment( AlignVCenter | AlignRight );
-    lo->addWidget( label );
-
-    modeW = new QComboBox( this );
+    modeW = new QComboBox( main );
     int i = 0;
     while (defaultText[i])
         modeW->insertItem( i18n(defaultText[i++]) );
-    lo->addWidget( modeW );
-
-    lo->addStretch(1);
-
-    leftCol->addStretch( 1 );
-
+    leftCol->addWidget( modeW );
 
+    leftCol->addStretch();
 
     // Preview
     QWidget* preview;
-    preview = new QWidget( this );
-    preview->setFixedSize( 220, 170 );
+    preview = new QWidget( main );
+    preview->setFixedSize( 220, 165 );
     preview->setBackgroundColor( black );
     preview->show();    // otherwise saver does not get correct size
     _saver = new KSWindsScreenSaver( preview->winId() );
-    across->addWidget(preview);
+    top->addWidget(preview);
 
     // Now that we have _saver...
     modeW->setCurrentItem( _saver->mode() );    // set before we connect
     connect( modeW, SIGNAL(activated(int)), _saver, SLOT(setMode(int)) );
-
-
-    // Buttons
-    QPushButton* button;
-    KButtonBox* bbox = new KButtonBox(this);
-    button = bbox->addButton( i18n("About"));
-    connect( button, SIGNAL(clicked()), SLOT(aboutPressed()) );
-
-    bbox->addStretch(1);
-
-    button = bbox->addButton( i18n("OK"));
-    connect( button, SIGNAL(clicked()), SLOT(slotOkPressed()) );
-
-    button = bbox->addButton(i18n("Cancel"));
-    connect( button, SIGNAL(clicked()), SLOT(reject()) );
-    bbox->layout();
-    top->addWidget(bbox);
-
-
-    top->freeze();
 }
 
 
@@ -764,7 +727,7 @@ KSWindsSetup::~KSWindsSetup()
 }
 
 
-void KSWindsSetup::aboutPressed()
+void KSWindsSetup::slotHelp()
 {
     KMessageBox::about(this,
         i18n("<h3>Solar Winds 1.0</h3>\n<p>Copyright (c) 2002 Terence M. Welsh<br>\n<a href=\"http://www.reallyslick.com/\">http://www.reallyslick.com/</a></p>\n\n<p>Ported to KDE by Karl Robillard</p>"),
@@ -775,7 +738,7 @@ void KSWindsSetup::aboutPressed()
 /**
   Ok pressed - save settings and exit
 */
-void KSWindsSetup::slotOkPressed()
+void KSWindsSetup::slotOk()
 {
     KConfig* config = KGlobal::config();
     config->setGroup("Settings");
