@@ -253,7 +253,12 @@ void KBannerSetup::slotCyclingColor(bool on)
    colorPush->setEnabled(!on);
    cyclingColor=on;
 
-   if (saver) saver->setCyclingColor( cyclingColor );
+   if ( saver )
+   {
+      saver->setCyclingColor( on );
+      if ( !on )
+         saver->setColor( fontColor );
+   }
 }
 
 void KBannerSetup::slotBold( bool state )
@@ -346,7 +351,7 @@ KBannerSaver::KBannerSaver( WId id ) : KScreenSaver( id )
 	readSettings();
 	initialize();
 	colorContext = QColor::enterAllocContext();
-	blank();
+	needBlank = TRUE;
 	timer.start( speed );
 	connect( &timer, SIGNAL( timeout() ), SLOT( slotTimeout() ) );
 }
@@ -362,7 +367,8 @@ KBannerSaver::~KBannerSaver()
 void KBannerSaver::setSpeed( int spd )
 {
 	timer.stop();
-	speed = 101-spd;
+	int inv = 100 - spd;
+	speed = 1 + ((inv * inv) / 100);
 	timer.start( speed );
 }
 
@@ -375,43 +381,35 @@ void KBannerSaver::setFont( const QString& family, int size, const QColor &color
 	bold = b;
 	italic = i;
 
-	blank();
 	initialize();
 }
 
 void KBannerSaver::setColor(QColor &color)
 {
-   fontColor=color;
+    fontColor = color;
+    cyclingColor = FALSE;
+    needUpdate = TRUE;
 }
 
 void KBannerSaver::setCyclingColor( bool on )
 {
-   cyclingColor=on;
-   if (cyclingColor)
-      fontColor.setHsv(0,SATURATION,VALUE);
+    cyclingColor = on;
+    needUpdate = TRUE;
 }
 
 void KBannerSaver::setMessage( const QString &msg )
 {
-    showTime=FALSE;
-    QPainter p (this );
-    p.setFont( font );
-    p.setPen( black );
-    p.drawText( xpos, ypos, message );
-
+    showTime = FALSE;
     message = msg;
     pixmapSize = QSize();
+    needBlank = TRUE;
 }
 
 void KBannerSaver::setTimeDisplay()
 {
-    QPainter p (this );
-    p.setFont( font );
-    p.setPen( black );
-    p.drawText( xpos, ypos, message );
-    showTime=TRUE;
-    message=KGlobal::locale()->formatTime(QTime::currentTime(), true);
+    showTime = TRUE;
     pixmapSize = QSize();
+    needBlank = TRUE;
 }
 
 // read settings from config file
@@ -420,7 +418,7 @@ void KBannerSaver::readSettings()
     KConfig *config = KGlobal::config();
     config->setGroup( "Settings" );
 
-   speed=101-config->readNumEntry("Speed",50);
+   setSpeed( config->readNumEntry("Speed",50) );
 
    message=config->readEntry("Message","KDE");
 
@@ -452,6 +450,7 @@ void KBannerSaver::initialize()
 	font = QFont( fontFamily, fsize, bold ? QFont::Bold : QFont::Normal, italic );
 
 	pixmapSize = QSize();
+	needBlank = TRUE;
 
 	xpos = width();
 	ypos = fsize + (int) ((double)(height()-fsize)*krnd->getDouble());
@@ -465,27 +464,32 @@ void KBannerSaver::slotTimeout()
 {
     if (cyclingColor)
     {
-        currentHue=(currentHue+4)%360;
+        int hueStep = speed/10;
+        currentHue=(currentHue+hueStep)%360;
         fontColor.setHsv(currentHue,SATURATION,VALUE);
     }
     if (showTime)
     {
         QString new_message = KGlobal::locale()->formatTime(QTime::currentTime(), true);
 	if( new_message != message )
-	    pixmapSize = QSize();
+	    needUpdate = TRUE;
 	message = new_message;
     }
-    if ( !pixmapSize.isValid())
+    if ( !pixmapSize.isValid() || cyclingColor || needUpdate || needBlank )
     {
         QRect rect = QFontMetrics( font ).boundingRect( message );
 	rect.setWidth( rect.width() + step );
-	pixmapSize = rect.size();
+	if ( rect.width() > pixmapSize.width() )
+	    pixmapSize.setWidth( rect.width() );
+	if ( rect.height() > pixmapSize.height() )
+	    pixmapSize.setHeight( rect.height() );
 	pixmap = QPixmap( pixmapSize );
 	pixmap.fill( black );
 	QPainter p( &pixmap );
 	p.setFont( font );
 	p.setPen( fontColor );
 	p.drawText( -rect.x(), -rect.y(), message );
+	needUpdate = FALSE;
     }
     xpos -= step;
     if ( xpos < -pixmapSize.width() ) {
@@ -495,12 +499,11 @@ void KBannerSaver::slotTimeout()
 	ypos = fsize + (int) ((double)(height()-2.0*fsize)*krnd->getDouble());
     }
 
-    bitBlt( this, xpos, ypos, &pixmap, 0, 0, pixmapSize.width(), pixmapSize.height());
-}
-
-void KBannerSaver::blank()
-{
+    if ( needBlank )
+    {
 	setBackgroundColor( black );
 	erase();
+	needBlank = FALSE;
+    }
+    bitBlt( this, xpos, ypos, &pixmap, 0, 0, pixmapSize.width(), pixmapSize.height());
 }
-
