@@ -31,8 +31,10 @@
 #include "science.h"
 #include "science.moc"
 
+#if defined Q_WS_X11 && !defined K_WS_QTONLY
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
+#endif
 
 #define SCI_DEFAULT_MODE          0
 #define SCI_DEFAULT_MOVEX         6
@@ -69,7 +71,7 @@ extern "C"
 
 static KScienceSaver *saver = 0;
 
-struct {
+static struct {
 	QString name;
 	bool inverseEnable;
 	} modeInfo[MAX_MODES];
