@@ -16,8 +16,13 @@
 #include <kglobal.h>
 #include "wave.h"
 #include "wave.moc"
+#ifdef Q_WS_MACX
+#include <OpenGL/glu.h>
+#include <OpenGL/gl.h>
+#else
 #include <GL/glu.h>
 #include <GL/gl.h>
+#endif
 #include <qimage.h>
 #include <kdebug.h>
 #include <qpainter.h>
