@@ -131,7 +131,7 @@ KPartSaver::KPartSaver( WId id )
 
         // queue files
         for( unsigned int n=0; n<m_files.count(); n++ )
-            queue( m_files[n] );
+            queue( KURL::fromPathOrURL( m_files[n] ) );
 
         // play files
         if( m_single )
