@@ -8,7 +8,7 @@
  *      	Fredrik Hglund <fredrik@kde.org>
  *
  *	Copyright (c) 2003
- *		Luciano Montanaro <mikelima@virgilio.it>
+ *		Luciano Montanaro <mikelima@cirulla.net>
  *
  *	Originally based on the KStep client.
  *
