@@ -12,6 +12,7 @@
 
 class QCheckBox;
 class QGroupBox;
+class QVBox;
 class QLabel;
 class QSlider;
 class QRadioButton;
@@ -41,7 +42,8 @@ class CdeConfig: public QObject
 		KConfig*   	cdeConfig;
 		QCheckBox* 	cbColorBorder;
 		QCheckBox* 	cbTitlebarButton;
-		QGroupBox* 	groupBox;
+		QCheckBox* 	cbDeeperBevels;
+		QHBox* 	        groupBox;
 		QGroupBox* 	gbSlider;
 		QButtonGroup*	bgAlign;
 		QSlider*   	widthSlider;
