@@ -260,7 +260,7 @@ void StdClient::init()
     QToolTip::add( button[ 0 ], i18n("Menu") );
     button[1] = new QToolButton( widget(), 0 );
     button[1]->setIconSet( isOnAllDesktops()?*pindown_pix:*pinup_pix );
-    QToolTip::add( button[ 1 ], isOnAllDesktops()?i18n("Un-Sticky"):i18n("Sticky")  );
+    QToolTip::add( button[ 1 ], isOnAllDesktops()?i18n("Unsticky"):i18n("Sticky")  );
 //    button[2] = new KWinToolButton( this, 0, i18n("?") );
     button[2] = NULL;
     button[3] = new QToolButton( widget(), 0 );
@@ -271,6 +271,7 @@ void StdClient::init()
     QToolTip::add( button[ 5 ], i18n("Close") );
 
     // explicitly set ArrowCursor.
+    button[0]->setCursor(ArrowCursor);
     button[1]->setCursor(ArrowCursor);
     button[3]->setCursor(ArrowCursor);
     button[4]->setCursor(ArrowCursor);
@@ -296,6 +297,7 @@ void StdClient::init()
 	hb->addItem( new QSpacerItem( 5, 0, QSizePolicy::Fixed, QSizePolicy::Expanding ) );
 	button[6]->setIconSet( isActive() ? *question_mark_pix : *dis_question_mark_pix);
 	connect( button[6], SIGNAL( clicked() ), this, ( SLOT( showContextHelp() ) ) );
+	button[6]->setCursor(ArrowCursor);
     }
 
     hb->addWidget( button[3] );
@@ -325,7 +327,7 @@ void StdClient::init()
     button[3]->setIconSet(isActive() ? *minimize_pix : *dis_minimize_pix);
     connect( button[3], SIGNAL( clicked() ), this, ( SLOT( minimize() ) ) );
     button[4]->setIconSet(isActive() ? *maximize_pix : *dis_maximize_pix);
-    connect( button[4], SIGNAL( clicked(int) ), this, ( SLOT( maxButtonClicked(int) ) ) );
+    connect( button[4], SIGNAL( clicked(ButtonState) ), this, ( SLOT( maxButtonClicked(ButtonState) ) ) );
     button[5]->setIconSet(isActive() ? *close_pix : *dis_close_pix);
     connect( button[5], SIGNAL( clicked() ), this, ( SLOT( closeWindow() ) ) );
 
@@ -406,7 +408,7 @@ void StdClient::desktopChange()
     bool s = isOnAllDesktops();
     button[1]->setIconSet( s?*pindown_pix:*pinup_pix );
     QToolTip::remove( button[ 1 ] );
-    QToolTip::add( button[1], s ? i18n("Un-Sticky") : i18n("Sticky") );
+    QToolTip::add( button[1], s ? i18n("Unsticky") : i18n("Sticky") );
 }
 
 void StdClient::paintEvent( QPaintEvent* )
@@ -466,29 +468,21 @@ void StdClient::iconChange()
  */
 void StdClient::menuButtonPressed()
 {
-    QPoint menupoint ( button[0]->rect().bottomLeft().x()-1,
-                       button[0]->rect().bottomLeft().y()+2 );
+    QRect menuRect = button[0]->rect();
+    menuRect.addCoords(-1, 0, +1, +2);
+    QPoint menuTop = button[0]->mapToGlobal(menuRect.topLeft());
+    QPoint menuBottom = button[0]->mapToGlobal(menuRect.bottomRight());
     KDecorationFactory* f = factory(); // needs to be saved before
-    showWindowMenu( button[0]->mapToGlobal( menupoint ));
+    showWindowMenu( QRect(menuTop, menuBottom) );
     if( !f->exists( this )) // destroyed, return immediately
         return;
     button[0]->setDown(false);
 }
 
 
-void StdClient::maxButtonClicked( int button )
+void StdClient::maxButtonClicked( ButtonState button )
 {
-    switch ( button  ){
-    case MidButton:
-	maximize( maximizeMode() ^ MaximizeVertical );
-	break;
-    case RightButton:
-	maximize( maximizeMode() ^ MaximizeHorizontal );
-	break;
-    default: //LeftButton:
-	maximize( maximizeMode() == MaximizeFull ? MaximizeRestore : MaximizeFull );
-	break;
-    }
+    maximize( button );
 }
 
 bool StdClient::eventFilter( QObject* o, QEvent* e )
@@ -526,7 +520,7 @@ QSize StdClient::minimumSize() const
 void StdClient::borders( int& left, int& right, int& top, int& bottom ) const
 {
     left = right = bottom = 6;
-    top = 6 + widget()->fontMetrics().lineSpacing();
+    top = 6 + widget()->fontMetrics().lineSpacing()+2;
 }
 
 void StdClient::resize( const QSize& s )
