@@ -1,6 +1,9 @@
 /*
   'OpenLook' kwin client
 
+  Porting to kde3.2 API 
+    Copyright 2003 Luciano Montanaro <mikelima@cirulla.net>
+  
   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to
   deal in the Software without restriction, including without limitation the
@@ -23,49 +26,45 @@
 #define KWIN_WEB_H
 
 #include <qptrlist.h>
+#include <qbutton.h>
 
-#include <kwin/client.h>
+#include <kdecoration.h>
+#include <kdecorationfactory.h>
 
 class QSpacerItem;
 
 namespace OpenLook
 {
-  using namespace KWinInternal;
-  
   class OpenLookButton;
 
-  class OpenLook : public Client
+  class OpenLook : public KDecoration
   {
     Q_OBJECT
-
     public:
 
-      OpenLook
-        (
-         Workspace *,
-         WId,
-         bool tool,
-         QWidget * parent = 0,
-         const char * name = 0
-        );
-
+      OpenLook(KDecorationBridge *b, KDecorationFactory *f);
       ~OpenLook();
+      void init();
 
     protected:
+      bool eventFilter(QObject *o, QEvent *e);
+      void resizeEvent(QResizeEvent *e);
+      void paintEvent(QPaintEvent *e);
+      void showEvent(QShowEvent *e);
 
-      virtual void captionChange(const QString &);
-      virtual void paintEvent(QPaintEvent *);
+      virtual void captionChange();
+      void desktopChange();
+      void activeChange();
+      void shadeChange();
+      void iconChange();
+      void maximizeChange();
+      void borders(int &left, int &right, int &top, int &bottom) const;
+      QSize minimumSize() const;
+      void resize( const QSize& );
       virtual void mouseDoubleClickEvent(QMouseEvent *);
-      virtual void mousePressEvent(QMouseEvent *);
-      virtual void mouseReleaseEvent(QMouseEvent *);
 
-      virtual void activeChange(bool);
-      virtual MousePosition mousePosition(const QPoint &) const;
-      virtual void animateIconifyOrDeiconify(bool);
-
-    protected slots:
-
-      void slotReset();
+      virtual Position mousePosition(const QPoint &) const;
+      virtual bool animateMinimize(bool);
 
     private:
 
@@ -90,10 +89,23 @@ namespace OpenLook
       void paintButton(QPainter &) const;
       void paintArrow(QPainter &) const;
 
-      bool            tool_;
-      bool            buttonDown_;
+      bool isButtonPress(QMouseEvent *);
+      bool isButtonRelease(QMouseEvent *);
+
       QSpacerItem   * titleSpacer_;
       QPoint          mousePressPoint_;
+      bool            tool_;
+      bool            buttonDown_;
+  };
+  
+  class DecorationFactory: public QObject, public KDecorationFactory
+  {
+  public:
+    DecorationFactory();
+    virtual ~DecorationFactory();
+    virtual KDecoration *createDecoration(KDecorationBridge *);
+    virtual bool reset(unsigned long changed);
+    QValueList< DecorationFactory::BorderSize > borderSizes() const;
   };
 }
 
