@@ -306,7 +306,7 @@ void SystemClient::init()
    g->addRowSpacing(2, 6);
 
    button[0] = new SystemButton(this, "close", NULL, i18n("Close"));
-   button[1] = new SystemButton(this, "sticky", NULL, i18n("On All Desktops"));
+   button[1] = new SystemButton(this, "sticky", NULL, i18n("On all desktops"));
    if(isOnAllDesktops())
       button[1]->setBitmap(unsticky_bits);
    else
@@ -411,18 +411,7 @@ void SystemClient::reset(unsigned long)
 
 void SystemClient::maxButtonClicked()
 {
-   switch ( button[3]->last_button  )
-   {
-   case MidButton:
-      maximize(maximizeMode() ^ MaximizeVertical );
-      break;
-   case RightButton:
-      maximize(maximizeMode() ^ MaximizeHorizontal );
-      break;
-   default: //LeftButton:
-      maximize(maximizeMode() == MaximizeFull ? MaximizeRestore : MaximizeFull );
-      break;
-   }
+   maximize( button[3]->last_button );
 }
 
 void SystemClient::resizeEvent( QResizeEvent* )
@@ -604,7 +593,7 @@ void SystemClient::iconChange()
 void SystemClient::desktopChange()
 {
    button[1]->setBitmap(isOnAllDesktops() ? unsticky_bits : sticky_bits);
-   button[1]->setTipText(isOnAllDesktops() ? i18n("Not On All Desktops") : i18n("On All Desktops"));
+   button[1]->setTipText(isOnAllDesktops() ? i18n("Not on all desktops") : i18n("On all desktops"));
 }
 
 /*void SystemClient::stickyChange(bool on)
