@@ -6,6 +6,9 @@
  *
  *	Drawing routines completely reimplemented from KDE3 HighColor, which was
  *	originally based on some stuff from the KDE2 HighColor.
+ *	Includes portions of framework code from KDE3 HighColor,
+ *          (C) 2001-2002 Karol Szwed <gallium@kde.org>,
+ *          (C) 2001-2002 Fredrik Hglund  <fredrik@kde.org>
  *
  *	This library is free software; you can redistribute it and/or
  *	modify it under the terms of the GNU Library General Public
@@ -467,12 +470,21 @@ void dotNETstyle::drawPrimitive(PrimitiveElement pe,
 
 		case PE_ScrollBarAddPage:
 		case PE_ScrollBarSubPage: {
+			// draw double buffered to avoid flicker...
+			QPixmap buffer(2,2);
+			QRect br(buffer.rect() );
+			QPainter bp(&buffer);
+ 
 			if (on || down) {
-				p->fillRect(r, QBrush(cg.mid().dark()));
+				bp.fillRect(br, QBrush(cg.mid().dark()));
 			} else {
-				p->fillRect(r, QBrush(cg.background()));
+				bp.fillRect(br, QBrush(cg.background()));
 			}
-			p->fillRect(r, QBrush(cg.background().light(), Dense4Pattern));
+			bp.fillRect(br, QBrush(cg.background().light(), Dense4Pattern));
+
+			bp.end();
+			p->drawTiledPixmap(r, buffer);
+
 			break;
 		}
 
@@ -544,7 +556,9 @@ void dotNETstyle::drawPrimitive(PrimitiveElement pe,
 			p->fillRect(r, color0);
 			p->setPen(color1);
 			p->setBrush(color1);
+			p->translate(r.x(), r.y());
 			p->drawPolygon(QPointArray(28, outline));
+			p->translate(-r.x(), -r.y());
 			break;
 		}
 
@@ -778,10 +792,11 @@ void dotNETstyle::drawControl(ControlElement element,
 				r.rect(&x, &y, &w, &h);
 
 				p->fillRect(x + 1, y + 1, w - 2, h - 2, cg.background().light());
+
 				if (reverseLayout) {
-					x = w - (int)(w * percent)+2;
-					w = w - 2 - x;
+					x += w - ((int)(w * percent));
 					y += 1; h -= 2;
+					w = ((int)(w * percent)) - 2;
 				} else {
 					x += 1; y += 1; h -= 2;
 					w = (int)(w * percent) - 2;
@@ -791,34 +806,29 @@ void dotNETstyle::drawControl(ControlElement element,
 
 				if (pb->progress() < pb->totalSteps()) {
 					p->setPen(cg.background().dark(115));
-					p->drawLine(x + w, y, x + w, h);
+					if (reverseLayout) {
+						p->drawLine(x - 1, y, x - 1, h);
+					} else {
+						p->drawLine(x + w, y, x + w, h);
+					}
 				}
 
 				if (pseudo3D) {
+					QPointArray corners;
 					if (reverseLayout) {
-						const QCOORD c[] = { x + 2, h, x + 2 , y, w + x , y, w + x , h };
-						const QPointArray corners(4, c);
-						p->setPen(cg.highlight().light(120));
-						p->drawConvexPolygon(corners);
-						p->setPen(cg.highlight().dark(120));
-						p->drawPolyline(corners, 0, 3);
-						if (roundedCorners) {
-							p->setPen(cg.background().dark());
-							p->drawPoints(corners);
-						}
-
+						const QCOORD c[] = { x, y, w + x, y, w + x, h, x, h };
+						corners = QPointArray(4, c);
 					} else {
 						const QCOORD c[] = { x, h, x, y, w, y, w, h };
-						const QPointArray corners(4, c);
-						p->setPen(cg.highlight().dark(120));
-						p->drawConvexPolygon(corners);
-						p->setPen(cg.highlight().light(120));
-						p->drawPolyline(corners, 0, 3);
-
-						if (roundedCorners) {
-							p->setPen(cg.background().dark());
-							p->drawPoints(corners);
-						}
+						corners = QPointArray(4, c);
+					}
+					p->setPen(cg.highlight().dark(120));
+					p->drawConvexPolygon(corners);
+					p->setPen(cg.highlight().light(120));
+					p->drawPolyline(corners, 0, 3);
+					if (roundedCorners) {
+						p->setPen(cg.background().dark());
+						p->drawPoints(corners);
 					}
 				}
 			}
@@ -1024,6 +1034,9 @@ void dotNETstyle::drawControl(ControlElement element,
 
 			p->drawText(r, text_flags, opt.tab()->text());
 
+			if (flags & Style_HasFocus)
+				drawPrimitive(PE_FocusRect, p, r, cg);
+
 			p->restore();
 			break;
 		}
@@ -1033,15 +1046,13 @@ void dotNETstyle::drawControl(ControlElement element,
 			QRect br = r;
 			bool btnDefault = button->isDefault();
 
-			if (btnDefault || button->autoDefault()) {
-				static int di = pixelMetric(PM_ButtonDefaultIndicator);
-				br.addCoords(di, di, -di, -di);
-			}
+			static int di = pixelMetric(PM_ButtonDefaultIndicator);
+			br.addCoords(di, di, -di, -di);
 
 			if (btnDefault) {
 				drawPrimitive(PE_ButtonDefault, p, r, cg, flags);
 			}
-
+			
 			drawPrimitive(PE_ButtonBevel, p, br, cg, flags);
 			break;
 		}
@@ -1051,8 +1062,8 @@ void dotNETstyle::drawControl(ControlElement element,
 			const bool enabled = flags & Style_Enabled;
 			const int text_flags = AlignVCenter | AlignHCenter | ShowPrefix |
 			                       DontClip | SingleLine;
-			int dx = 0;
-
+			QRect ur(r);
+			
 			if (flags & Style_Down) {
 				p->translate(pixelMetric(PM_ButtonShiftHorizontal),
 				             pixelMetric(PM_ButtonShiftVertical));
@@ -1065,47 +1076,48 @@ void dotNETstyle::drawControl(ControlElement element,
 			if (pb->iconSet() && !pb->iconSet()->isNull()) {
 				QIconSet::Mode mode = enabled ? QIconSet::Normal : QIconSet::Disabled;
 				QPixmap pixmap = pb->iconSet()->pixmap(QIconSet::Small, mode);
-				QRect pr(0, 0, pixmap.width(), pixmap.height());
-
-				pr.moveCenter(r.center());
-
-				if (pb->text()) {
-					dx = r.height() - pixmap.height();
-					pr.moveLeft((2 * dx));
+				
+				if (!pb->text().isEmpty())
+				{
+					const int TextToIconMargin = 3;
+					int length = pixmap.width() + TextToIconMargin
+					              + p->fontMetrics().size(ShowPrefix, pb->text()).width();
+					int offset = (r.width() - length)/2;
+					
+					p->drawPixmap( r.x() + offset, r.y() + r.height() / 2 - pixmap.height() / 2, pixmap );
+					ur.addCoords(offset + pixmap.width() + TextToIconMargin, 0, -offset, 0);
 				}
+				else
+				{
+					if (!pb->pixmap())
+						p->drawPixmap(r.x() + r.width()/2 - pixmap.width()/2, r.y() + r.height() / 2 - pixmap.height() / 2,
+										pixmap);
+					else  //icon + pixmap. Ugh. 
+						p->drawPixmap(r.x() + pb->isDefault() ? 8 : 4 , r.y() + r.height() / 2 - pixmap.height() / 2, pixmap);
+				}
+			}
 
-				p->drawPixmap(pr.topLeft(), pixmap);
-			} else if (pb->pixmap() && !pb->text()) {
+			if (pb->pixmap() && !pb->text()) {
 				QRect pr(0, 0, pb->pixmap()->width(), pb->pixmap()->height());
 				pr.moveCenter(r.center());
 				p->drawPixmap(pr.topLeft(), *pb->pixmap());
 			}
 
 			if (useTextShadows && pb->text() && enabled) {
-				if (pb->iconSet() && !pb->iconSet()->isNull()) {
-					QRect tr(p->boundingRect(r, text_flags, pb->text()));
-					tr.moveCenter(r.center());
-					tr.moveBy(dx + 1, 1);
-					p->setPen((flags & Style_Down ? cg.highlight().dark(135) : cg.background().dark(115)));
-					p->drawText(tr, text_flags, pb->text());
-				} else {
-					p->setPen((flags & Style_Down ? cg.highlight().dark(135) : cg.background().dark(115)));
-					p->drawText(r.x()+1, r.y()+1, r.width(), r.height(), text_flags, pb->text());
-				}
+				p->setPen((flags & Style_Down ? cg.highlight().dark(135) : cg.background().dark(115)));
+				p->drawText(ur.x()+1, ur.y()+1, ur.width(), ur.height(), text_flags, pb->text());
 			}
 
 			if (pb->text()) {
 				p->setPen(enabled ? cg.foreground() : pb->palette().disabled().buttonText());
-				if (pb->iconSet() && !pb->iconSet()->isNull()) {
-					QRect tr(p->boundingRect(r, text_flags, pb->text()));
-					tr.moveCenter(r.center());
-					tr.moveBy(dx, 0);
-					p->drawText(tr, text_flags, pb->text());
-				} else {
-					p->drawText(r, text_flags, pb->text());
-				}
+				p->drawText(ur, text_flags, pb->text());
 			}
 
+			if ( flags & Style_HasFocus )
+				drawPrimitive( PE_FocusRect, p,
+				               visualRect( subRect( SR_PushButtonFocusRect, widget ), widget ),
+				               cg, flags );
+
 			break;
 		}
 
@@ -1682,6 +1694,14 @@ QRect dotNETstyle::subRect(SubRect r, const QWidget *widget) const
 			return querySubControlMetrics( CC_ComboBox, widget, SC_ComboBoxEditField );
 		}
 
+		case SR_PushButtonFocusRect: {
+			QRect rect = widget->rect();
+			int margin = pixelMetric(PM_ButtonDefaultIndicator, widget) + pixelMetric(PM_DefaultFrameWidth, widget) + 2;
+
+			rect.addCoords(margin, margin, -margin, -margin);
+			return rect;
+		}
+
 		case SR_ProgressBarGroove:
 		case SR_ProgressBarContents:
 		case SR_ProgressBarLabel: {
@@ -1910,44 +1930,40 @@ QSize dotNETstyle::sizeFromContents(ContentsType t,
 		}
 
 		case CT_PushButton: {
-			const QPushButton *button = (const QPushButton *)widget;
-			QSize ret = QCommonStyle::sizeFromContents(t, widget, s, opt);
-			int w = ret.width() + 6, h = ret.height() - 2, tp = 0;;
-			int dbi = (pixelMetric(PM_ButtonDefaultIndicator, widget) * 2) + 6;
-			int mw = 80 - dbi, mh = 30 - dbi;
-			bool btnDefault = button->isDefault() || button->autoDefault();
-			bool hasText = (button->text() && !button->text().isNull());
+			const QPushButton* button = (const QPushButton*) widget;
+			int w  = s.width();
+			int h  = s.height();
+			int bm = pixelMetric( PM_ButtonMargin, widget );
+			int fw = pixelMetric( PM_DefaultFrameWidth, widget ) * 2;
 
-			if (btnDefault) {
-				mw += dbi;
-				mh += dbi;
-			}
-			if (button->iconSet() && !button->iconSet()->isNull()) {
-				w += button->iconSet()->pixmap(QIconSet::Small, QIconSet::Normal).width();
-				if (!hasText) {
-					w = button->iconSet()->pixmap(QIconSet::Small, QIconSet::Normal).width();
-					h = button->iconSet()->pixmap(QIconSet::Small, QIconSet::Normal).height();
-				}
-			} else if (button->pixmap() && !button->pixmap()->isNull()) {
-				w += button->pixmap()->width();
-				if (!hasText) {
-					w = button->pixmap()->width();
-					h = button->pixmap()->height();
-				}
-			}
+			//We use bold font sometimes, so that make take more space than Qt allocated.
+			QFontMetrics origFM = button->fontMetrics();
+			QFontMetrics boldFM = QFontMetrics(QFont(button->font().family(), button->font().pointSize(), 75));
+			int origTextWidth = origFM.size(ShowPrefix, button->text()).width();
+			int boldTextWidth = boldFM.size(ShowPrefix, button->text()).width();
 
-			if (!hasText) {
-				return QSize(w + 6, h + 6);
-			}
-			if (!inheritsKHTML(widget)) {
-				QFontMetrics fm(QFont(button->font().family(), button->font().pointSize(), 75));
-				fm.boundingRect(button->text()).rect(&tp, &tp, &w, &h);
+			if (boldTextWidth > origTextWidth) //this might not happen in particular when text is empty
+				w += boldTextWidth - origTextWidth;
+			
+			w += bm + fw;
+			h += bm + fw;
 
-				w = (w < mw ? mw : w + dbi);
-				h = (h < mh ? mh : h + dbi);
+			// Ensure we stick to standard width and heights.
+			if ( button->isDefault() || button->autoDefault() ) {
+				if ( w < 80 && !button->pixmap() )
+					w = 80;
 			}
+				
+			// Compensate for default indicator. Doing it for all widgets lets us
+			// workaround changes in auto-default behavior in KDialogBase in 3.3
+			int di = pixelMetric( PM_ButtonDefaultIndicator );
+			w += di * 2;
+			h += di * 2;
 
-			return QSize(w, h);
+			if ( h < 22 )
+				h = 22;
+
+			return QSize( w, h );
 		}
 
 		case CT_ComboBox: {
